package FaDe;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 * The FeatureSet class contains a set of the features currently supported by the library, which can be populated with calculated values.
 * 
 * @author Giorgio Luparia
 */
public class FeatureSet implements Serializable {
    public enum Feature {
		KeystrokeDurationMin,				// duration of a keystroke (minimum)
		KeystrokeDurationAve,				// duration of a keystroke (average)
		KeystrokeDurationMax,				// duration of a keystroke (maximum)
		WritingSpeedMin,					// keystroke speed (minimum)
		WritingSpeedAve,					// keystroke speed (average)
		WritingSpeedMax,					// keystroke speed (maximum)
		RelativeFrequencyOfKeyENTER,		// number of ENTER strokes over every stroke
		RelativeFrequencyOfKeySPACEBAR,		// number of SPACEBAR strokes over every stroke
		RelativeFrequencyOfKeyTAB,			// number of TAB strokes over every stroke
		RelativeFrequencyOfKeyCANCEL,		// number of CANCEL strokes over every stroke
		RelativeFrequencyOfKeyBACKSPACE,	// number of BACKSPACE strokes over every stroke
		RelativeFrequencyOfKeyARROW,		// number of ARROW strokes over every stroke
		RelativeFrequencyOfKeyCONTROL,		// number of CONTROL strokes over every stroke
		RelativeFrequencyOfKeySHIFT,		// number of SHIFT strokes over every stroke
		RelativeFrequencyOfKeyALT,			// number of ALT strokes over every stroke
		RelativeDurationOfKeyENTER,			// duration of ENTER strokes over every stroke
		RelativeDurationOfKeySPACEBAR,		// duration of SPACEBAR strokes over every stroke
		RelativeDurationOfKeyTAB,			// duration of TAB strokes over every stroke
		RelativeDurationOfKeyCANCEL,		// duration of CANCEL strokes over every stroke
		RelativeDurationOfKeyBACKSPACE,		// duration of BACKSPACE strokes over every stroke
		RelativeDurationOfKeyARROW,			// duration of ARROW strokes over every stroke
		RelativeDurationOfKeyCONTROL,		// duration of CONTROL strokes over every stroke
		RelativeDurationOfKeySHIFT,			// duration of SHIFT strokes over every stroke
		RelativeDurationOfKeyALT,			// duration of ALT strokes over every stroke
		MouseclickDurationMin,				// duration of a mouse click (minimum)
		MouseclickDurationAve,				// duration of a mouse click (average)
		MouseclickDurationMax,				// duration of a mouse click (maximum)
		MouseDoubleClickDurationMin,		// duration of a mouse double click (minimum)
		MouseDoubleClickDurationAve,		// duration of a mouse double click (average)
		MouseDoubleClickDurationMax,		// duration of a mouse double click (maximum)
		MouseSpeedMin,						// mouse movement speed (minimum)
		MouseSpeedAve,						// mouse movement speed (average)
		MouseSpeedMax,						// mouse movement speed (maximum)
		MouseMovementDeviationMin,			// mouse deviation on the axis perpendicular to the movement (minimum)
		MouseMovementDeviationAve,			// mouse deviation on the axis perpendicular to the movement (average)
		MouseMovementDeviationMax,			// mouse deviation on the axis perpendicular to the movement (maximum)
		MouseHesitationsPerMovementMin,		// mouse hesitations (very short pauses) per movement (minimum)
		MouseHesitationsPerMovementAve,		// mouse hesitations (very short pauses) per movement (average)
		MouseHesitationsPerMovementMax		// mouse hesitations (very short pauses) per movement (maximum)
    }
    
    private Map<Feature, Double> set;
    
    public FeatureSet() {
        set = new HashMap<FeatureSet.Feature, Double>();
        for (Feature f : Feature.values())
            set.put(f, null);
    }
    
    public void setFeature(Feature feature, double value) {
        set.put(feature, value);
    }
    
    public Double getFeature(Feature feature) {
        return set.get(feature);
    }
}
