package FaDe;

import java.io.Serializable;

/**
 * The Instant class represents an istant in time with microseconds precision.
 * 
 * @author Giorgio Luparia
 */
class Instant implements Comparable<Instant>, Serializable {
    private long microseconds;

	/**
	 * Class constructor.
	 * 
	 * @param seconds		time since Unix Epoch (seconds)
	 * @param microseconds	time since Unix Epoch (microseconds fraction)
	 */
    public Instant(int seconds, int microseconds) {
        this.microseconds = 1000000 * seconds + microseconds;
    }
    
	/**
	 * Returns the number of seconds since Unix Epoch.
	 * 
	 * @return	seconds since Standard Epoch
	 */
    public int getSeconds() {
        return (int) (microseconds / 1000000);
    }
    
	/**
	 * Returns the microseconds fraction of time since the Unix Epoch (from the last istant being at an integer second distance from Unix Epoch).
	 * 
	 * @return	microseconds fraction since Unix Epoch
	 */
    public int getMicroseconds() {
        return (int) (microseconds % 1000000);
    }
    
	/**
	 * Returns the distance between this istant and the specified one.
	 * The distance is negative if the specified istant comes after this one.
	 * The distance is zero if the two objects represent the same istant (with microseconds precision).
	 * The distance is positive if the specified istant comes before this one.
	 * 
	 * @param	instant	the istant to subtract
	 * @return			the distance in microseconds
	 */
    public long minus(Instant instant) {
        return this.microseconds - instant.microseconds;
    }
    
    @Override
    public String toString() {
        return new String(Integer.toString(getSeconds()) + "s+" + Integer.toString(getMicroseconds()) + "us");
    }

    public int compareTo(Instant o) {
        return (int) (this.microseconds - o.microseconds);
    }
}
