package FaDe;

import java.io.Serializable;

/**
 * The KeyStroke class represent a user's key stroke.
 * 
 * @author Giorgio Luparia
 */
class KeyStroke extends Event implements Serializable {
    private Instant pressTime, releaseTime;
    private Key key;

	/**
	 * Class constructor.
	 * 
	 * @param pressTime		the istant the key was pressed
	 * @param releaseTime	the istant the key was released
	 * @param key			the key descriptor
	 */
    public KeyStroke(Instant pressTime, Instant releaseTime, Key key) {
        this.pressTime = pressTime;
        this.releaseTime = releaseTime;
        this.key = key;
    }
    
	/**
	 * Returns the amount of time (in microseconds) the key has been pressed.
	 * 
	 * @return the amount of time (in microseconds) the key has been pressed
	 */
    public long getStrokeDurationInMicroseconds() {
        return releaseTime.minus(pressTime);
    }
    
	/**
	 * Returns the key descriptor.
	 * 
	 * @return the key descriptor
	 */
    public Key getKey() {
        return key;
    }
	
	public Instant getInstant() {
		return pressTime;
	}
    
    @Override
    public String toString() {
        return new String(key + " - " + getStrokeDurationInMicroseconds());
    }
}
