package FaDe;

import java.io.Serializable;

/**
 * The MouseButtonStroke class represent a user's mouse button stroke.
 * 
 * @author Giorgio Luparia
 */
class MouseButtonStroke extends Event implements Serializable {
    private Instant pressTime, releaseTime;

	/**
	 * Class constructor.
	 * 
	 * @param pressTime		the istant the button was pressed
	 * @param releaseTime	the istant the button was released
	 */
    public MouseButtonStroke(Instant pressTime, Instant releaseTime) {
        this.pressTime = pressTime;
        this.releaseTime = releaseTime;
    }
    
	/**
	 * Returns the istant at which the button was pressed.
	 * 
	 * @return the istant at which the button was pressed
	 */
    public Instant getPressTime() {
        return pressTime;
    }
	
	/**
	 * Returns the istant at which the button was released.
	 * 
	 * @return the istant at which the button was released
	 */
	public Instant getReleaseTime() {
		return releaseTime;
	}
    
	/**
	 * Returns the amount of time (in microseconds) the button has been pressed.
	 * 
	 * @return the amount of time (in microseconds) the button has been pressed
	 */
    public long getStrokeDurationInMicroseconds() {
        return releaseTime.minus(pressTime);
    }
	
	public Instant getInstant() {
		return getPressTime();
	}
    
    @Override
    public String toString() {
        return new String("MouseButtonStroke - " + getStrokeDurationInMicroseconds());
    }
}
